==> coin2_2.3.0.orig.tar.gz: Coin-2.3.0/include/Inventor/details/SoNodeKitDetail.h <==
#ifndef COIN_SONODEKITDETAIL_H
#define COIN_SONODEKITDETAIL_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#include <Inventor/details/SoSubDetail.h>
#include <Inventor/SbName.h>

class SoBaseKit;
class SoNode;


class COIN_DLL_API SoNodeKitDetail : public SoDetail {
  typedef SoDetail inherited;

  SO_DETAIL_HEADER(SoNodeKitDetail);

public:
  SoNodeKitDetail(void);
  virtual ~SoNodeKitDetail();

  static void initClass(void);
  virtual SoDetail * copy(void) const;

  void setNodeKit(SoBaseKit * kit);
  SoBaseKit * getNodeKit(void) const;

  void setPart(SoNode * part);
  SoNode * getPart(void) const;

  void setPartName(const SbName & name);
  const SbName & getPartName(void) const;

protected:
  SoBaseKit * myNodeKit;
  SoNode * myPart;
  SbName myPartName;
};

#endif // !COIN_SONODEKITDETAIL_H

==> coin2_2.4.4.orig.tar.gz: Coin-2.4.4/include/Inventor/details/SoNodeKitDetail.h <==
#ifndef COIN_SONODEKITDETAIL_H
#define COIN_SONODEKITDETAIL_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#include <Inventor/details/SoSubDetail.h>
#include <Inventor/SbName.h>

class SoBaseKit;
class SoNode;


class COIN_DLL_API SoNodeKitDetail : public SoDetail {
  typedef SoDetail inherited;

  SO_DETAIL_HEADER(SoNodeKitDetail);

public:
  SoNodeKitDetail(void);
  virtual ~SoNodeKitDetail();

  static void initClass(void);
  virtual SoDetail * copy(void) const;

  void setNodeKit(SoBaseKit * kit);
  SoBaseKit * getNodeKit(void) const;

  void setPart(SoNode * part);
  SoNode * getPart(void) const;

  void setPartName(const SbName & name);
  const SbName & getPartName(void) const;

protected:
  SoBaseKit * myNodeKit;
  SoNode * myPart;
  SbName myPartName;
};

#endif // !COIN_SONODEKITDETAIL_H
